@@ -285,7 +285,6 @@ where
 	}
 }
 
-#[cfg(not(tarpaulin_include))]
 impl<O, T> Debug for BitSlice<O, T>
 where
 	O: BitOrder,
@@ -313,8 +312,13 @@ where
 	}
 }
 
-/// Renders a `BitSlice` handle as its pointer representation.
-#[cfg(not(tarpaulin_include))]
+/** Renders a `BitSlice` handle as its pointer representation.
+
+This does not enable `{:p}` in a format string, as there is a blanket `Pointer`
+implementation for all references, and unsized types cannot format by
+themselves. It is only reachable by forwarding from another format marker, such
+as `Debug`.
+**/
 impl<O, T> Pointer for BitSlice<O, T>
 where
 	O: BitOrder,
@@ -378,8 +382,8 @@ macro_rules! fmt {
 				yet grant access to trait constants for use in constant
 				expressions within generics.
 				*/
-				let mut w: [u8; (usize::BITS as usize / $blksz) + 2] =
-					[b'0'; (usize::BITS as usize / $blksz) + 2];
+				const W: usize = <usize as BitMemory>::BITS as usize / $blksz;
+				let mut w: [u8; W + 2] = [b'0'; W + 2];
 				//  Write the prefix symbol into the buffer.
 				w[1] = $pfx;
 				//  This closure does the main work of rendering a bit slice as
